core.version — PyZMQ v2.1.1dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »

# core.version

## Module: `core.version`

PyZMQ and 0MQ version functions.

## Functions

`zmq.core.version.` `pyzmq_version`()

  Return the version of pyzmq as a string.

`zmq.core.version.` `zmq_version`()

  Return the version of ZeroMQ itself as a string.

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »